import { EventEmitter, Directive, ElementRef, Renderer2, Input, Output, Renderer, NgModule } from '@angular/core';
import { RouterModule } from '@angular/router';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class GridStackDirective {
    /**
     * @param {?} el
     * @param {?} renderer
     */
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
        this.options = {
            cellHeight: 80,
            verticalMargin: 10
        };
        this.gridInited = new EventEmitter();
        renderer.setAttribute(el.nativeElement, 'class', 'grid-stack');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const self = this;
        /** @type {?} */
        let renderer = this.renderer;
        /** @type {?} */
        let nativeElement = this.el.nativeElement;
        /** @type {?} */
        let animate = this.animate ? 'yes' : 'no';
        renderer.setAttribute(nativeElement, 'data-gs-width', String(this.w));
        if (animate === 'yes') {
            renderer.setAttribute(nativeElement, 'data-gs-animate', animate);
        }
        // tslint:disable-next-line: variable-name
        /** @type {?} */
        let _default = {
            cellHeight: 80,
            verticalMargin: 10
        };
        /** @type {?} */
        let opt = Object.assign(_default, this.options);
        // TODO: listen to an event here instead of just waiting for the time to expire 
        setTimeout((/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            let $grid = $('.grid-stack').gridstack(opt);
            self.gridInited.emit($grid);
        }), 10);
    }
}
GridStackDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line:directive-selector
                selector: '[gridStack]'
            },] }
];
/** @nocollapse */
GridStackDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
GridStackDirective.propDecorators = {
    w: [{ type: Input }],
    animate: [{ type: Input }],
    options: [{ type: Input }],
    gridInited: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UUID {
    /**
     * @param {?} len
     * @param {?=} radix
     * @return {?}
     */
    static uuid(len, radix) {
        /** @type {?} */
        const chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('');
        /** @type {?} */
        let uuid = [];
        /** @type {?} */
        let i;
        radix = radix !== undefined ? radix : chars.length;
        if (len) {
            // Compact form
            // tslint:disable-next-line: no-bitwise  
            for (i = 0; i < len; i++)
                uuid[i] = chars[0 | Math.random() * radix];
        }
        else {
            // rfc4122, version 4 form
            /** @type {?} */
            let r;
            // rfc4122 requires these characters
            uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
            uuid[14] = '4';
            // Fill in random data.  At i==19 set the high bits of clock sequence as
            // per rfc4122, sec. 4.1.5
            for (i = 0; i < 36; i++) {
                if (!uuid[i]) {
                    // tslint:disable-next-line: no-bitwise
                    r = 0 | Math.random() * 16;
                    // tslint:disable-next-line: no-bitwise
                    uuid[i] = chars[(i === 19) ? (r & 0x3) | 0x8 : r];
                }
            }
        }
        return uuid.join('');
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class GridStackItemDirective {
    /**
     * @param {?} el
     * @param {?} renderer
     */
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
        renderer.setElementAttribute(el.nativeElement, 'class', 'grid-stack-item');
        this.id = UUID.uuid(10);
    }
    // tslint:disable-next-line:use-life-cycle-interface
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        let renderer = this.renderer;
        /** @type {?} */
        let nativeElement = this.el.nativeElement;
        /** @type {?} */
        let cannotResize = this.canResize ? 'yes' : 'no';
        renderer.setElementAttribute(nativeElement, 'data-gs-x', String(this.x));
        renderer.setElementAttribute(nativeElement, 'data-gs-y', String(this.y));
        renderer.setElementAttribute(nativeElement, 'data-gs-width', String(this.w));
        renderer.setElementAttribute(nativeElement, 'data-gs-height', String(this.h));
        renderer.setElementAttribute(nativeElement, 'data-gs-id', String(this.id));
        renderer.setElementAttribute(nativeElement, 'id', String(this.id));
        if (this.minWidth) {
            renderer.setElementAttribute(nativeElement, 'data-gs-min-width', String(this.minWidth));
        }
        if (cannotResize === 'yes') {
            renderer.setElementAttribute(nativeElement, 'data-gs-no-resize', cannotResize);
        }
    }
}
GridStackItemDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line:directive-selector
                selector: '[gridStackItem]'
            },] }
];
/** @nocollapse */
GridStackItemDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer }
];
GridStackItemDirective.propDecorators = {
    x: [{ type: Input }],
    y: [{ type: Input }],
    w: [{ type: Input }],
    h: [{ type: Input }],
    minWidth: [{ type: Input }],
    canResize: [{ type: Input }],
    id: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DraggableDirective {
    /**
     * @param {?} el
     * @param {?} renderer2
     */
    constructor(el, renderer2) {
        this.el = el;
        this.renderer2 = renderer2;
        this.stackSelector = '.k-draggable';
        this.appendTo = 'body';
        this.helper = 'clone';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        let self = this;
        self.renderer2.addClass(this.el.nativeElement, 'k-draggable');
        $(this.el.nativeElement).draggable({
            helper: this.helper,
            revert: "invalid",
            stack: this.stackSelector,
            appendTo: this.appendTo,
            drag: (/**
             * @param {?} event
             * @param {?} ui
             * @return {?}
             */
            function (event, ui) {
                if (self.drag) {
                    self.drag(event, ui);
                }
            }),
            start: (/**
             * @param {?} event
             * @param {?} ui
             * @return {?}
             */
            function (event, ui) {
                if (self.start) {
                    self.start(event, ui);
                }
            }),
            stop: (/**
             * @param {?} event
             * @param {?} ui
             * @return {?}
             */
            function (event, ui) {
                if (self.stop) {
                    self.stop(event, ui);
                }
            }),
        });
    }
}
DraggableDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line:directive-selector
                selector: '[draggable]'
            },] }
];
/** @nocollapse */
DraggableDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
DraggableDirective.propDecorators = {
    stop: [{ type: Input, args: ['stop',] }],
    start: [{ type: Input, args: ['start',] }],
    drag: [{ type: Input, args: ['drag',] }],
    stackSelector: [{ type: Input, args: ['stack',] }],
    appendTo: [{ type: Input, args: ['appendTo',] }],
    helper: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DroppableDirective {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        this.accept = '.accepted';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        let self = this;
        $(this.el.nativeElement).droppable({
            accept: this.accept,
            drop: (/**
             * @param {?} event
             * @param {?} ui
             * @return {?}
             */
            function (event, ui) {
                if (self.drop) {
                    self.drop(event, ui);
                }
            }),
            over: (/**
             * @param {?} event
             * @param {?} ui
             * @return {?}
             */
            function (event, ui) {
                if (self.over) {
                    self.over(event, ui);
                }
            }),
            out: (/**
             * @param {?} event
             * @param {?} ui
             * @return {?}
             */
            function (event, ui) {
                if (self.out) {
                    self.out(event, ui);
                }
            })
        });
    }
}
DroppableDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line:directive-selector
                selector: '[droppable]'
            },] }
];
/** @nocollapse */
DroppableDirective.ctorParameters = () => [
    { type: ElementRef }
];
DroppableDirective.propDecorators = {
    drop: [{ type: Input, args: ['drop',] }],
    over: [{ type: Input, args: ['over',] }],
    out: [{ type: Input, args: ['out',] }],
    accept: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class GridStackModule {
    constructor() {
    }
}
GridStackModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    GridStackDirective,
                    GridStackItemDirective,
                    DraggableDirective,
                    DroppableDirective
                ],
                exports: [
                    GridStackDirective,
                    GridStackItemDirective,
                    DraggableDirective,
                    DroppableDirective
                ],
                imports: [
                    CommonModule,
                    RouterModule
                ],
                providers: []
            },] }
];
/** @nocollapse */
GridStackModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Layout {
    /**
     * @param {?} id
     * @param {?} name
     * @param {?} items
     */
    constructor(id, name, items) {
        this.name = '';
        this.items = [];
        this.name = name;
        this.items = items;
        this.id = id;
    }
}
class LayoutItem {
    /**
     * @param {?=} js
     */
    constructor(js) {
        this.height = 4; // 比列 *cellheight
        // 比列 *cellheight
        this.width = 4; // 比列 *width
        if (js !== undefined) {
            this.height = js['height'];
            this.width = js['width'];
            this.minHeight = js['minHeight'];
            this.minWidth = js['minWidth'];
            this.maxHeight = js['maxHeight'];
            this.maxWidth = js['maxWidth'];
            this.x = js['x'];
            this.y = js['y'];
            this.componentName = js['componentName'];
            if (js['id'] !== undefined)
                this._id = js['id'];
            else {
                this._id = UUID.uuid(10);
            }
            this.dataOptins = js['dataOptins'];
        }
    }
    /**
     * @return {?}
     */
    get id() {
        return this._id;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    set id(val) {
        this._id = val;
    }
    /**
     * @param {?} js
     * @return {?}
     */
    static fromJS(js) {
        return new LayoutItem(js);
    }
}
class CreateLayoutEntity {
}
class DeleteLayoutEntity {
}

export { CreateLayoutEntity, DeleteLayoutEntity, DraggableDirective, DroppableDirective, GridStackDirective, GridStackItemDirective, GridStackModule, Layout, LayoutItem };
//# sourceMappingURL=kst-gridstack.js.map
